.qwa-buzzer {
    width: 80vw;
    height: 55vh;
    margin: 4vh 10vw;
    font-size: calc(10vw + 10vh);
    cursor: pointer;
}

.qwa-select-disable {
    -webkit-user-select: none;
    -khtml-user-select: none;
    -moz-user-select: none;
    -o-user-select: none;
    user-select: none;
}
