<!DOCTYPE html>
<html>

<head>
    <link rel="icon" type="image/x-icon" href="/static/icons/favicon.ico">
    <link rel="stylesheet" href="https://fonts.googleapis.com/icon?family=Material+Icons">
    <link rel="stylesheet" href="https://code.getmdl.io/1.3.0/material.purple-deep_purple.min.css">
    <link rel="stylesheet" href="static/css/common.css">
    <script src="//code.jquery.com/jquery-3.3.1.min.js"></script>
    <script type="text/javascript" src="//cdnjs.cloudflare.com/ajax/libs/socket.io/1.3.6/socket.io.min.js"></script>
    <script defer src="https://code.getmdl.io/1.3.0/material.min.js"></script>
    <script src="static/js/{{ page_name }}.js"></script>
    <link rel="stylesheet" href="static/dialog-polyfill/dialog-polyfill.css">
    <script src="static/dialog-polyfill/dialog-polyfill.js"></script>
</head>

<body>
    {% block body %}
    {% endblock %}
</body>

</html>